@@ -123,6 +123,12 @@ int offset; } static_surface;
 
 typedef void (*gamgi_tetra) (void *surface, int *v0, int *v1, int *v2, int *v3);
 
+/*************************************************************
+ * radial Laguerre polynomials start here: the factor r**l   *
+ * (l = angular quantum number) is supressed as this cancels *
+ * with the factor 1 / r**l from the Legendre functions      *
+ *************************************************************/
+
 static double static_1s (double r)
 {
 /******************
@@ -147,7 +153,7 @@ static double static_2p (double r)
  * n = 2, l = 1 *
  ****************/
 
-return r;
+return 1;
 }
 
 static double static_3s (double r)
@@ -167,18 +173,16 @@ static double static_3p (double r)
  * n = 3, l = 1 *
  ****************/
 
-return r * (4 - r);
+return 4 - r;
 }
 
 static double static_3d (double r)
 {
-double r2 = r * r;
-
 /****************
  * n = 3, l = 2 *
  ****************/
 
-return r2;
+return 1;
 }
 
 static double static_4s (double r)
@@ -190,7 +194,7 @@ double r3 = r2 * r;
  * n = 4, l = 0 *
  ****************/
 
-return (24 - 36 * r + 12 * r2 - r3);
+return 24 - 36 * r + 12 * r2 - r3;
 }
 
 static double static_4p (double r)
@@ -201,29 +205,25 @@ double r2 = r * r;
  * n = 4, l = 1 *
  ****************/ 
 
-return r * (20 - 10 * r + r2); 
+return 20 - 10 * r + r2; 
 }
 
 static double static_4d (double r)
 {
-double r2 = r * r;
-
 /****************
  * n = 4, l = 2 *
  ****************/
 
-return (6 - r) * r2;
+return 6 - r;
 }
 
 static double static_4f (double r)
 {
-double r3 = r * r * r;
-
 /****************
  * n = 4, l = 3 *
  ****************/
 
-return r3;
+return 1;
 }
 
 static double static_5s (double r)
@@ -236,7 +236,7 @@ double r4 = r3 * r;
  * n = 5, l = 0 *
  ****************/
 
-return (120 - 240 * r + 120 * r2 - 20 * r3 + r4);
+return 120 - 240 * r + 120 * r2 - 20 * r3 + r4;
 }
 
 static double static_5p (double r)
@@ -248,7 +248,7 @@ double r3 = r2 * r;
  * n = 5, l = 1 *
  ****************/
 
-return (120 - 90 * r + 18 * r2 - r3) * r;
+return 120 - 90 * r + 18 * r2 - r3;
 }
 
 static double static_5d (double r)
@@ -259,30 +259,25 @@ double r2 = r * r;
  * n = 5, l = 2 *
  ****************/
 
-return (42 - 14 * r + r2) * r2;
+return 42 - 14 * r + r2;
 }
 
 static double static_5f (double r)
 {
-double r3 = r * r * r;
-
 /****************
  * n = 5, l = 3 *
  ****************/
 
-return (8 - r) * r3;
+return 8 - r;
 }
 
 static double static_5g (double r)
 {
-double r2 = r * r;
-double r4 = r2 * r2;
-
 /****************
  * n = 5, l = 4 *
  ****************/
 
-return r4;
+return 1;
 }
 
 static double static_6s (double r)
@@ -296,7 +291,7 @@ double r5 = r4 * r;
  * n = 6, l = 0 *
  ****************/
 
-return (720 - 1800 * r + 1200 * r2 - 300 * r3 + 30 * r4 - r5);
+return 720 - 1800 * r + 1200 * r2 - 300 * r3 + 30 * r4 - r5;
 }
 
 static double static_6p (double r)
@@ -309,7 +304,7 @@ double r4 = r3 * r;
  * n = 6, l = 1 *
  ****************/
 
-return (840 - 840 * r + 252 * r2 - 28 * r3 + r4) * r;
+return 840 - 840 * r + 252 * r2 - 28 * r3 + r4;
 }
 
 static double static_6d (double r)
@@ -321,44 +316,36 @@ double r3 = r2 * r;
  * n = 6, l = 2 *
  ****************/
 
-return (336 - 168 * r + 24 * r2 - r3) * r2;
+return 336 - 168 * r + 24 * r2 - r3;
 }
 
 static double static_6f (double r)
 {
 double r2 = r * r;
-double r3 = r2 * r;
 
 /****************
  * n = 6, l = 3 *
  ****************/
 
-return (72 - 18 * r + r2) * r3;
+return 72 - 18 * r + r2;
 }
 
 static double static_6g (double r)
 {
-double r2 = r * r;
-double r4 = r2 * r2;
-
 /****************
  * n = 6, l = 4 *
  ****************/
 
-return (10 - r) * r4;
+return 10 - r;
 }
 
 static double static_6h (double r)
 {
-double r2 = r * r;
-double r4 = r2 * r2;
-double r5 = r4 * r;
-
 /****************
  * n = 6, l = 5 *
  ****************/
 
-return r5;
+return 1;
 }
 
 static void static_radial (int n, int l, double *c, gamgi_radial *f)
@@ -408,6 +395,12 @@ if (n == 6)
 *c = 1 / *c;
 }
 
+/**************************************************************
+ * angular Legendre functions start here: the factor 1 / r**l *
+ * (l = angular quantum number) is supressed as this cancels  *
+ * with the factor r**l from the Laguerre polynomials         *
+ **************************************************************/
+
 static double static_s (double x, double y, double z, double r)
 {
 /****************
@@ -423,7 +416,7 @@ static double static_py (double x, double y, double z, double r)
  * l = 1, m = -1 *
  *****************/
 
-return y / r;
+return y;
 }
 
 static double static_pz (double x, double y, double z, double r)
@@ -432,7 +425,7 @@ static double static_pz (double x, double y, double z, double r)
  * l = 1, m = 0 *
  ****************/
 
-return z / r;
+return z;
 }
 
 static double static_px (double x, double y, double z, double r)
@@ -441,29 +434,25 @@ static double static_px (double x, double y, double z, double r)
  * l = 1, m = +1 *
  *****************/
 
-return x / r;
+return x;
 }
 
 static double static_dxy (double x, double y, double z, double r)
 {
-double r2 = r * r;
-
 /****************
  * l = 2, m = -2 *
  ****************/
 
-return (x * y) / r2;
+return x * y;
 }
 
 static double static_dyz (double x, double y, double z, double r)
 {
-double r2 = r * r;
-
 /****************
  * l = 2, m = -1 *
  ****************/
 
-return (y * z) / r2;
+return y * z;
 }
 
 static double static_dz2 (double x, double y, double z, double r)
@@ -475,172 +464,157 @@ double r2 = r * r;
  * l = 2, m = 0 *
  ****************/
 
-return (3 * z2 - r2) / r2;
+return 3 * z2 - r2;
 }
 
 static double static_dxz (double x, double y, double z, double r)
 {
-double r2 = r * r;
-
 /****************
  * l = 2, m = 1 *
  ****************/
 
-return (x * z) / r2;
+return x * z;
 }
 
 static double static_dx2_y2 (double x, double y, double z, double r)
 {
 double x2 = x * x;
 double y2 = y * y;
-double r2 = r * r;
 
 /****************
  * l = 2, m = 2 *
  ****************/
 
-return (x2 - y2) / r2;
+return x2 - y2;
 }
 
 static double static_fy_3x2_y2 (double x, double y, double z, double r)
 {
 double x2 = x * x;
 double y2 = y * y;
-double r3 = r * r * r;
 
 /*****************
  * l = 3, m = -3 *
  *****************/
 
-return y * (3 * x2 - y2) / r3;
+return y * (3 * x2 - y2);
 }
 
 static double static_fxyz (double x, double y, double z, double r)
 {
-double r3 = r * r * r;
-
 /*****************
  * l = 3, m = -2 *
  *****************/
 
-return (x * y * z) / r3;
+return x * y * z;
 }
 
 static double static_fyz2 (double x, double y, double z, double r)
 {
 double z2 = z * z;
 double r2 = r * r;
-double r3 = r2 * r;
 
 /*****************
  * l = 3, m = -1 *
  *****************/
 
-return y * (5 * z2 - r2) / r3;
+return y * (5 * z2 - r2);
 }
 
 static double static_fz3 (double x, double y, double z, double r)
 {
 double z2 = z * z;
 double r2 = r * r;
-double r3 = r2 * r;
 
 /****************
  * l = 3, m = 0 *
  ****************/
 
-return z * (5 * z2 - 3 * r2) / r3;
+return z * (5 * z2 - 3 * r2);
 }
 
 static double static_fxz2 (double x, double y, double z, double r)
 {
 double z2 = z * z;
 double r2 = r * r;
-double r3 = r2 * r;
 
 /****************
  * l = 3, m = 1 *
  ****************/
 
-return x * (5 * z2 - r2) / r3;
+return x * (5 * z2 - r2);
 }
 
 static double static_fz_x2_y2 (double x, double y, double z, double r)
 {
 double x2 = x * x;
 double y2 = y * y;
-double r3 = r * r * r;
 
 /****************
  * l = 3, m = 2 *
  ****************/
 
-return z * (x2 - y2) / r3;
+return z * (x2 - y2);
 }
 
 static double static_fx_x2_3y2 (double x, double y, double z, double r)
 {
 double x2 = x * x;
 double y2 = y * y;
-double r3 = r * r * r;
 
 /****************
  * l = 3, m = 3 *
  ****************/
 
-return x * (x2 - 3 * y2) / r3;
+return x * (x2 - 3 * y2);
 }
 
 static double static_gxy_x2_y2 (double x, double y, double z, double r)
 {
 double x2 = x * x;
 double y2 = y * y;
-double r4 = r * r * r * r;
 
 /*****************
  * l = 4, m = -4 *
  *****************/
 
-return x * y * (x2 - y2) / r4;
+return x * y * (x2 - y2);
 }
 
 static double static_gzy3 (double x, double y, double z, double r)
 {
 double x2 = x * x;
 double y2 = y * y;
-double r4 = r * r * r * r;
 
 /*****************
  * l = 4, m = -3 *
  *****************/
 
-return y * z * (3 * x2 - y2) / r4;
+return y * z * (3 * x2 - y2);
 }
 
 static double static_gz2_xy (double x, double y, double z, double r)
 {
 double z2 = z * z;
 double r2 = r * r;
-double r4 = r2 * r2;
 
 /*****************
  * l = 4, m = -2 *
  *****************/
 
-return x * y * (7 * z2 - r2) / r4;
+return x * y * (7 * z2 - r2);
 }
 
 static double static_gz3y (double x, double y, double z, double r)
 {
 double z2 = z * z;
 double r2 = r * r;
-double r4 = r2 * r2;
 
 /*****************
  * l = 4, m = -1 *
  *****************/
 
-return y * z * (7 * z2 - 3 * r2) / r4;
+return y * z * (7 * z2 - 3 * r2);
 }
 
 static double static_gz4 (double x, double y, double z, double r)
@@ -654,20 +628,19 @@ double r4 = r2 * r2;
  * l = 4, m = 0 *
  ****************/
 
-return (35 * z4 - 30 * z2 * r2 + 3 * r4) / r4;
+return (35 * z4 - 30 * z2 * r2 + 3 * r4);
 }
 
 static double static_gz3x (double x, double y, double z, double r)
 {
 double z2 = z * z;
 double r2 = r * r;
-double r4 = r2 * r2;
 
 /****************
  * l = 4, m = 1 *
  ****************/
 
-return x * z * (7 * z2 - 3 * r2) / r4;
+return x * z * (7 * z2 - 3 * r2);
 }
 
 static double static_gz2_x2_y2 (double x, double y, double z, double r)
@@ -676,26 +649,24 @@ double x2 = x * x;
 double y2 = y * y;
 double z2 = z * z;
 double r2 = r * r;
-double r4 = r2 * r2;
 
 /****************
  * l = 4, m = 2 *
  ****************/
 
-return (x2 - y2) * (7 * z2 - r2) / r4;
+return (x2 - y2) * (7 * z2 - r2);
 }
 
 static double static_gzx3 (double x, double y, double z, double r)
 {
 double x2 = x * x;
 double y2 = y * y;
-double r4 = r * r * r * r;
 
 /*****************
  * l = 4, m = 3 *
  *****************/
 
-return x * z * (x2 - 3 * y2) / r4;
+return x * z * (x2 - 3 * y2);
 }
 
 static double static_gx4_y4 (double x, double y, double z, double r)
@@ -704,13 +675,12 @@ double x2 = x * x;
 double x4 = x2 * x2;
 double y2 = y * y;
 double y4 = y2 * y2;
-double r4 = r * r * r * r;
 
 /*****************
  * l = 4, m = 4 *
  *****************/
 
-return (x4 + y4 - 6 * x2 * y2) / r4;
+return (x4 + y4 - 6 * x2 * y2);
 }
 
 static double static_hy5 (double x, double y, double z, double r)
@@ -720,28 +690,24 @@ double x4 = x2 * x2;
 double y2 = y * y;
 double y3 = y2 * y;
 double y5 = y3 * y2;
-double r2 = r * r;
-double r5 = r2 * r2 * r;
 
 /*****************
  * l = 5, m = -5 *
  *****************/
 
-return (y5 - 10 * x2 * y3 + 5 * x4 * y) / r5;
+return (y5 - 10 * x2 * y3 + 5 * x4 * y);
 }
 
 static double static_hxyz_x2_y2 (double x, double y, double z, double r)
 {
 double x2 = x * x;
 double y2 = y * y;
-double r2 = r * r;
-double r5 = r2 * r2 * r;
 
 /*****************
  * l = 5, m = -4 *
  *****************/
 
-return x * y * z * (x2 - y2) / r5;
+return x * y * z * (x2 - y2);
 }
 
 static double static_hz2y3 (double x, double y, double z, double r)
@@ -750,26 +716,24 @@ double y3 = y * y * y;
 double x2 = x * x;
 double z2 = z * z;
 double r2 = r * r;
-double r5 = r2 * r2 * r;
 
 /*****************
  * l = 5, m = -3 *
  *****************/
 
-return (3 * x2 * y - y3) * (9 * z2 - r2) / r5;
+return (3 * x2 * y - y3) * (9 * z2 - r2);
 }
 
 static double static_hz3_xy (double x, double y, double z, double r)
 {
 double z3 = z * z * z;
 double r2 = r * r;
-double r5 = r2 * r2 * r;
 
 /*****************
  * l = 5, m = -2 *
  *****************/
 
-return x * y * (3 * z3 - z * r2) / r5;
+return x * y * (3 * z3 - z * r2);
 }
 
 static double static_hz4y (double x, double y, double z, double r)
@@ -778,13 +742,12 @@ double z2 = z * z;
 double z4 = z2 * z2;
 double r2 = r * r;
 double r4 = r2 * r2;
-double r5 = r4 * r;
 
 /*****************
  * l = 5, m = -1 *
  *****************/
 
-return y * (21 * z4 - 14 * z2 * r2 + r4) / r5;
+return y * (21 * z4 - 14 * z2 * r2 + r4);
 }
 
 static double static_hz5 (double x, double y, double z, double r)
@@ -794,13 +757,12 @@ double z3 = z2 * z;
 double z5 = z3 * z2;
 double r2 = r * r;
 double r4 = r2 * r2;
-double r5 = r4 * r;
 
 /****************
  * l = 5, m = 0 *
  ****************/
 
-return (63 * z5 - 70 * z3 * r2 + 15 * z * r4) / r5;
+return (63 * z5 - 70 * z3 * r2 + 15 * z * r4);
 }
 
 static double static_hz4x (double x, double y, double z, double r)
@@ -809,13 +771,12 @@ double z2 = z * z;
 double z4 = z2 * z2;
 double r2 = r * r;
 double r4 = r2 * r2;
-double r5 = r4 * r;
 
 /****************
  * l = 5, m = 1 *
  ****************/
 
-return x * (21 * z4 - 14 * z2 * r2 + r4) / r5;
+return x * (21 * z4 - 14 * z2 * r2 + r4);
 }
 
 static double static_hz3_x2_y2 (double x, double y, double z, double r)
@@ -824,13 +785,12 @@ double x2 = x * x;
 double y2 = y * y;
 double z3 = z * z * z;
 double r2 = r * r;
-double r5 = r2 * r2 * r;
 
 /****************
  * l = 5, m = 2 *
  ****************/
 
-return (x2 - y2) * (3 * z3 - z * r2) / r5;
+return (x2 - y2) * (3 * z3 - z * r2);
 }
 
 static double static_hz2x3 (double x, double y, double z, double r)
@@ -839,13 +799,12 @@ double x3 = x * x * x;
 double y2 = y * y;
 double z2 = z * z;
 double r2 = r * r;
-double r5 = r2 * r2 * r;
 
 /****************
  * l = 5, m = 3 *
  ****************/
 
-return (x3 - 3 * x * y2) * (9 * z2 - r2) / r5;
+return (x3 - 3 * x * y2) * (9 * z2 - r2);
 }
 
 static double static_hz_x4_y4 (double x, double y, double z, double r)
@@ -854,14 +813,12 @@ double x2 = x * x;
 double x4 = x2 * x2;
 double y2 = y * y;
 double y4 = y2 * y2;
-double r2 = r * r;
-double r5 = r2 * r2 * r;
 
 /****************
  * l = 5, m = 4 *
  ****************/
 
-return z * (x4 + y4 - 6 * x2 * y2) / r5;
+return z * (x4 + y4 - 6 * x2 * y2);
 }
 
 static double static_hx5 (double x, double y, double z, double r)
@@ -871,14 +828,12 @@ double x3 = x2 * x;
 double x5 = x3 * x2;
 double y2 = y * y;
 double y4 = y2 * y2;
-double r2 = r * r;
-double r5 = r2 * r2 * r;
 
 /****************
  * l = 5, m = 5 *
  ****************/
 
-return (x5 - 10 * x3 * y2 + 5 * x * y4) / r5;
+return (x5 - 10 * x3 * y2 + 5 * x * y4);
 }
 
 static void static_angular (int l, int m, double *c, gamgi_angular *f)
@@ -1166,9 +1121,9 @@ char *above;
 gamgi_radial function_r;
 gamgi_angular function_a;
 double *origin;
-double za, r, ho, rho;
+double r, ho, rho;
 double density, radius, width, f, x, y, z;
-double constant, constant_z, constant_r, constant_a;
+double constant;
 int n_points, n;
 
 /********************
@@ -1176,28 +1131,24 @@ int n_points, n;
  ********************/
 
 orbital = surface->orbital;
-
-static_radial (orbital->n, orbital->l, &constant_r, &function_r);
-static_angular (orbital->l, orbital->m, &constant_a, &function_a);
-
-za = orbital->charge / GAMGI_CHEM_A0;
-ho = 2 * za / orbital->n;
-constant_z = pow (za, 1.5);
-constant = constant_z * constant_r * constant_a;
+function_r = surface->function_r;
+function_a = surface->function_a;
+constant = surface->constant;
+ho = surface->ho;
 
 /*****************
  * get user data *
  *****************/
 
 density = orbital->density;
+width = surface->width;
 n_points = surface->n_points;
 radius = orbital->radius;
-width = surface->width;
 
-surface->origin[0] = radius * (a - 1);
-surface->origin[1] = radius * (b - 1);
-surface->origin[2] = radius * (c - 1);
 origin = surface->origin;
+origin[0] = radius * (a - 1);
+origin[1] = radius * (b - 1);
+origin[2] = radius * (c - 1);
 
 /*******************
  * set above array *
@@ -1214,7 +1165,6 @@ for (c = 0; c < n_points; c++)
       {
       x = origin[0] + a * width;
       r = x * x + y * y + z * z;
-      if (r < GAMGI_CHEM_ORBITAL_R_MIN) r = GAMGI_CHEM_ORBITAL_R_MIN;
       r = sqrt (r);
 
       rho = r * ho;
@@ -1494,15 +1444,12 @@ else
   a = surface->a;
   b = surface->b;
   c = surface->c;
-
   f[0] = origin[0] + width * (a + v[0]);
   f[1] = origin[1] + width * (b + v[1]);
   f[2] = origin[2] + width * (c + v[2]);
 
   r = f[0] * f[0] + f[1] * f[1] + f[2] * f[2];
-  if (r < GAMGI_CHEM_ORBITAL_R_MIN) r = GAMGI_CHEM_ORBITAL_R_MIN;
   r = sqrt (r);
-
   rho = r * surface->ho;
   f[3] = surface->constant * exp (-rho / 2) * (*function_r) (rho) *
   (*function_a) (f[0], f[1], f[2], r);
