@@ -719,6 +719,19 @@ gamgi_enum structure, filter;
 direction = gamgi_engine_create_direction ();
 gamgi_engine_start_direction (direction);
 
+/******************************************
+ * get name (set empty default, to handle *
+ * it later, when u,v,w indices are known *
+ ******************************************/
+
+if (gamgi_gtk_object_name (dialog, "entry_direction",
+"", direction->object.name) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid Direction name", window);
+  gamgi_engine_remove_direction (direction);
+  return;
+  }
+
 /***********************************
  * this unneeded initialization    *
  * avoids a O3 compilation warning *
@@ -794,6 +807,7 @@ if (direction->reference == GAMGI_ENGINE_CELL)
     gamgi_gtk_direction_list_create (direction, cell,
     structure, filter, thickness, dlist, pole, trace);
 
+  gamgi_gtk_direction_list_cancel (NULL, window);
   while (dlist != NULL)
     dlist = gamgi_engine_dlist_remove_start (dlist);
   gamgi_engine_remove_direction (direction);
@@ -808,6 +822,8 @@ if (direction->reference == GAMGI_ENGINE_ATOM)
    * the direction type is needed because of the rotation next *
    *************************************************************/
 
+  if (strcmp (direction->object.name, "") == 0)
+    strcpy (direction->object.name, "Direction");
   direction->type = GAMGI_PHYS_LINE;
   direction->vectors = GAMGI_PHYS_DIRECTION_VECTORS;
 
