@@ -416,12 +416,6 @@ if (static_range_decrease (value, range_new) == TRUE)
 return TRUE;
 }
 
-static void static_reset (gamgi_window *window)
-{
-free (list.indices);
-gamgi_gtk_direction_list_start (window);
-}
-
 static void static_row (GtkListStore *store, int u, int v, int w)
 {
 GtkTreeIter iter;
@@ -509,22 +503,10 @@ if (static_update (value, window) == TRUE) static_show (window);
 static_hide (window);
 }
 
-static void static_cancel (GtkWidget *widget, void *data)
-{
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *button;
-
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
-gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
-
-gamgi_gtk_direction_list (NULL, data);
-}
-
 static void static_delete (GtkWidget *widget,
 GdkEventButton *event, void *data)
 {
-static_cancel (widget, data);
+gamgi_gtk_direction_list_cancel (widget, data);
 }
 
 static void static_include (GtkWidget *widget, void *data)
@@ -779,7 +761,7 @@ gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_grab_focus (button);
 g_signal_connect (button, "clicked",
-G_CALLBACK (static_cancel), window);
+G_CALLBACK (gamgi_gtk_direction_list_cancel), window);
 gtk_widget_show (button);
 
 gtk_widget_show (dialog);
@@ -789,9 +771,6 @@ static void static_direction (gamgi_direction *direction,
 gamgi_cell *cell, gamgi_enum structure, gamgi_enum filter,
 double thickness, gamgi_dlist *dlist, gamgi_enum pole, gamgi_enum trace)
 {
-sprintf (direction->object.name, "[%d.%d.%d]",
-direction->uvw[0], direction->uvw[1], direction->uvw[2]);
-
 if (cell->type == GAMGI_PHYS_PROJECTION)
   gamgi_phys_direction_projection (direction, cell, pole, trace);
 else
@@ -854,9 +833,27 @@ list.range[2] = INT_MAX; list.range[3] = -INT_MAX;
 list.range[4] = INT_MAX; list.range[5] = -INT_MAX;
 }
 
+void gamgi_gtk_direction_list_cancel (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *button;
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
+
+gamgi_gtk_direction_list (NULL, data);
+}
+
 void gamgi_gtk_direction_list_destroy (GtkWidget *widget, void *data)
 {
-static_reset (GAMGI_CAST_WINDOW data);
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+
+free (list.indices);
+gamgi_gtk_direction_list_start (window);
+
+if (window->dialog1 != NULL)
+  gamgi_gtk_dialog_task1_remove (widget, window);
 }
 
 void gamgi_gtk_direction_list (GtkWidget *widget, void *data)
@@ -883,11 +880,7 @@ else
    * restart first level indices *
    *********************************/
 
-  static_reset (window);
-
-  if (window->dialog1 != NULL)
-    gamgi_gtk_dialog_task1_remove (widget, window);
-
+  gamgi_gtk_direction_list_destroy (NULL, window);
   gamgi_gtk_direction_create_uvw (TRUE, window);
   }
 }
