@@ -82,6 +82,77 @@ double translation[3], rotation[3];
 float red, green, blue;
 double scale; } cache;
 
+static void static_name (gamgi_window *window, char *name)
+{
+gamgi_direction *direction;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+GtkWidget *button;
+char string[GAMGI_ENGINE_STRING];
+int active;
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_direction");
+
+direction = GAMGI_CAST_DIRECTION gamgi_gtk_object_number (dialog,
+"entry_direction", GAMGI_ENGINE_DIRECTION, window, string);
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
+
+if (active == TRUE || direction == NULL)
+  {
+  sprintf (string, "%s", name);
+  }
+else
+  {
+  if (strcmp (name, "") == 0)
+    sprintf (string, "%s %d", direction->object.name, direction->object.number);
+  else
+    sprintf (string, "%s %d", name, direction->object.number);
+  }
+
+gtk_entry_set_text (GTK_ENTRY (entry), string);
+}
+
+static void static_indices (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+char token[GAMGI_ENGINE_TOKEN] = "";
+const char *name;
+gamgi_bool out;
+int u, v, w;
+
+/*************************
+ * Get direction indices *
+ *************************/
+
+out = TRUE;
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_u");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+out = out && gamgi_io_token_int_scan (name, &u, -INT_MAX, INT_MAX);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+out = out && gamgi_io_token_int_scan (name, &v, -INT_MAX, INT_MAX);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_w");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+out = out && gamgi_io_token_int_scan (name, &w, -INT_MAX, INT_MAX);
+
+out = out && (u != 0 || v != 0 || w != 0);
+
+/*************************
+ * update direction name *
+ *************************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_direction");
+if (out == TRUE) gamgi_phys_direction_name (u, v, w, token);
+static_name (window, token);
+}
+
 static void static_atom_remove (gamgi_direction *direction, gamgi_bool *link)
 {
 if (cache.structure != GAMGI_CHEM_STRUCTURE_LINK)
@@ -1819,6 +1890,14 @@ if (class == GAMGI_ENGINE_DIRECTION)
   entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
   sprintf (string, "%.*f", GAMGI_MATH_DECIMAL_SCALE, direction->object.scale);
   gtk_entry_set_text (GTK_ENTRY (entry), string);
+
+  /**************************************************************************
+   * set direction identification at the end,after automatic name setting! *
+   **************************************************************************/
+
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_direction");
+  sprintf (string, "%s %d", object->name, object->number);
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
   }
 
 else if (class == GAMGI_ENGINE_CELL)
@@ -2081,6 +2160,8 @@ entry = gtk_entry_new ();
 gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 0, 1, GTK_EXPAND, GTK_FILL, 0, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+g_signal_connect (entry, "changed",
+G_CALLBACK (static_indices), window);
 g_object_set_data (G_OBJECT (dialog), "entry_u", entry);
 gtk_widget_show (entry);
 
@@ -2088,6 +2169,8 @@ entry = gtk_entry_new ();
 gtk_table_attach (GTK_TABLE (table), entry, 3, 4, 0, 1, GTK_EXPAND, GTK_FILL, 0, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+g_signal_connect (entry, "changed",
+G_CALLBACK (static_indices), window);
 g_object_set_data (G_OBJECT (dialog), "entry_v", entry);
 gtk_widget_show (entry);
 
@@ -2095,6 +2178,8 @@ entry = gtk_entry_new ();
 gtk_table_attach (GTK_TABLE (table), entry, 5, 6, 0, 1, GTK_EXPAND, GTK_FILL, 0, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+g_signal_connect (entry, "changed",
+G_CALLBACK (static_indices), window);
 g_object_set_data (G_OBJECT (dialog), "entry_w", entry);
 gtk_widget_show (entry);
 
