@@ -20,7 +20,6 @@
 #include "gamgi_engine_dlist.h"
 #include "gamgi_gtk_select.h"
 #include "gamgi_gtk_dialog.h"
-#include "gamgi_gtk_text_config.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_io_token.h"
 #include "gamgi_math_quaternion.h"
@@ -53,7 +52,7 @@ gamgi_window *window = GAMGI_CAST_WINDOW data;
  **************************************************************/
 
 gamgi_engine_dlist_remove_all (static_before);
-gamgi_global_selection_link (gamgi->texts);
+gamgi_global_selection_link (gamgi->orbitals);
 gamgi_mesa_select_reset (window);
 }
 
@@ -66,7 +65,7 @@ GtkTreeStore *store;
 store = gtk_tree_store_new (2, G_TYPE_STRING, G_TYPE_POINTER);
 while (dlist != NULL)
   {
-  gamgi_gtk_select_text (store, NULL, GAMGI_CAST_TEXT dlist->data);
+  gamgi_gtk_select_orbital (store, NULL, GAMGI_CAST_ORBITAL dlist->data);
   dlist = dlist->next;
   }
 
@@ -82,15 +81,15 @@ gamgi_dlist *dlist = NULL;
 switch (scope)
   {
   case STATIC_GAMGI:
-  dlist = gamgi_engine_dlist_text_gamgi (NULL);
+  dlist = gamgi_engine_dlist_orbital_gamgi (NULL);
   break;
 
   case STATIC_WINDOW:
-  dlist = gamgi_engine_dlist_text_window (window, NULL);
+  dlist = gamgi_engine_dlist_orbital_window (window, NULL);
   break;
 
   case STATIC_LAYER:
-  dlist = gamgi_engine_dlist_text_layer (window->layer, NULL);
+  dlist = gamgi_engine_dlist_orbital_layer (window->layer, NULL);
   break;
 
   case STATIC_BEFORE:
@@ -98,7 +97,7 @@ switch (scope)
   break;
 
   case STATIC_CURRENT:
-  dlist = gamgi->texts;
+  dlist = gamgi->orbitals;
   break;
   }
 
@@ -130,56 +129,6 @@ if (scope != STATIC_BEFORE && scope != STATIC_CURRENT)
   gamgi_engine_dlist_remove_all (dlist);
 }
 
-static int static_font (gamgi_enum font)
-{
-switch (font)
-  {
-  case GAMGI_IO_SUN_ROMAN: return 0;
-  case GAMGI_IO_SUN_ROMAN_MONO: return 1;
-
-  case GAMGI_IO_HERSHEY_SANS:
-  case GAMGI_IO_DEJAVU_SANS:
-  return 2;
-
-  case GAMGI_IO_HERSHEY_SANS_BOLD:
-  case GAMGI_IO_DEJAVU_SANS_BOLD:
-  return 3;
-
-  case GAMGI_IO_DEJAVU_SANS_ITALIC: return 4;
-  case GAMGI_IO_DEJAVU_SANS_BOLD_ITALIC: return 5;
-
-  case GAMGI_IO_HERSHEY_SERIF:
-  case GAMGI_IO_DEJAVU_SERIF:
-  return 6;
-
-  case GAMGI_IO_HERSHEY_SERIF_BOLD:
-  case GAMGI_IO_DEJAVU_SERIF_BOLD:
-  return 7;
-
-  case GAMGI_IO_DEJAVU_SERIF_ITALIC: return 8;
-  case GAMGI_IO_DEJAVU_SERIF_BOLD_ITALIC: return 9;
-
-  case GAMGI_IO_HERSHEY_SCRIPT: return 10;
-  case GAMGI_IO_HERSHEY_SCRIPT_BOLD: return 11;
-  case GAMGI_IO_HERSHEY_GOTHIC_ENGLISH: return 12;
-  case GAMGI_IO_HERSHEY_GOTHIC_GERMAN: return 13;
-  case GAMGI_IO_HERSHEY_GOTHIC_ITALIAN: return 14;
-  case GAMGI_IO_HERSHEY_SYMBOL_SANS: return 15;
-  case GAMGI_IO_HERSHEY_SYMBOL_SERIF: return 16;
-  case GAMGI_IO_HERSHEY_SYMBOL_SERIF_BOLD: return 17;
-  case GAMGI_IO_DEJAVU_MONO: return 18;
-  case GAMGI_IO_DEJAVU_MONO_BOLD: return 19;
-  case GAMGI_IO_DEJAVU_MONO_ITALIC: return 20;
-  case GAMGI_IO_DEJAVU_MONO_BOLD_ITALIC: return 21;
-  }
-
-/*******************
- * impossible case *
- *******************/
-
-return -1;
-}
-
 static void static_method_style (char *label, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
@@ -214,32 +163,6 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
-static void static_method_font (char *label, gamgi_window *window)
-{
-GtkWidget *dialog = window->dialog0;
-GtkWidget *widget;
-GtkWidget *hbox;
-GtkWidget *combo;
-GtkCellRenderer *renderer;
-
-widget = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), label);
-hbox = gtk_widget_get_parent (widget);
-gtk_widget_destroy (widget);
-
-combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), label, combo);
-gtk_widget_show (combo);
-
-gamgi_gtk_text_config_all (combo);
-
-renderer = gtk_cell_renderer_text_new ();
-gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
-gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
-
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
-}
-
 static void static_method (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
@@ -284,11 +207,6 @@ else if (strcmp (name, "Style") == 0)
   static_method_style ("widget_max", window);
   }
 
-else if (strcmp (name, "Font") == 0)
-  {
-  static_method_font ("widget_min", window);
-  static_method_font ("widget_max", window);
-  }
 else
   {
   gamgi_gtk_select_method_default ("widget_min", window);
@@ -327,7 +245,7 @@ gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
  * show current list and reset selection method *
  ************************************************/
 
-static_model (gamgi->texts, window);
+static_model (gamgi->orbitals, window);
 static_method (NULL, window);
 }
 
@@ -438,69 +356,10 @@ for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
 return dlist_new;
 }
 
-static gamgi_dlist *static_ok_contents (gamgi_dlist *dlist_old,
-gamgi_bool action, gamgi_window *window)
-{
-gamgi_text *text;
-gamgi_dlist *dlist, *dlist_new;
-gamgi_bool condition;
-char min[GAMGI_ENGINE_TOKEN];
-char max[GAMGI_ENGINE_TOKEN];
-char *name;
-int length_max, length_string;
-
-/********************
- * get range limits *
- ********************/
-
-if (gamgi_gtk_select_entry_alpha (GAMGI_IO_FONT_ASCII,
-GAMGI_ENGINE_TOKEN, min, max, window) == FALSE) return NULL;
-
-/******************************
- * get list of selected texts *
- ******************************/
-
-dlist_new = NULL;
-for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
-  {
-  text = GAMGI_CAST_TEXT dlist->data;
-  
-  /********************************************************* 
-   *  min must be at the beginning, max must be at the end *
-   *********************************************************/
-
-  condition = TRUE;
-  if (strcmp (min, "") != 0)
-    {
-    name = strstr (text->string, min);
-    if (name != text->string) condition = FALSE;
-    }
-  if (strcmp (max, "") != 0)
-    {
-    length_max = strlen (max);
-    length_string = strlen (text->string);
-    if (length_string < length_max) condition = FALSE;
-    else
-      {
-      name = strstr (text->string + length_string - length_max, max);
-      if (name == NULL) condition = FALSE;
-      }
-    }
-
-  if (condition != action)
-    {
-    dlist_new = gamgi_engine_dlist_add_start (dlist_new);
-    dlist_new->data = text;
-    }
-  }
-
-return dlist_new;
-}
-
 static gamgi_dlist *static_ok_x (gamgi_dlist *dlist_old,
 gamgi_bool action, gamgi_window *window)
 {
-gamgi_text *text;
+gamgi_orbital *orbital;
 gamgi_dlist *dlist, *dlist_new;
 gamgi_bool condition;
 double min, max;
@@ -519,13 +378,13 @@ DBL_MAX, &min, &max, window) == FALSE) return NULL;
 dlist_new = NULL;
 for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
   {
-  text = GAMGI_CAST_TEXT dlist->data;
-  condition = (text->origin[0] >= min && text->origin[0] <= max);
+  orbital = GAMGI_CAST_ORBITAL dlist->data;
+  condition = (orbital->origin[0] >= min && orbital->origin[0] <= max);
 
   if (condition != action)
     {
     dlist_new = gamgi_engine_dlist_add_start (dlist_new);
-    dlist_new->data = text;
+    dlist_new->data = orbital;
     }
   }
 
@@ -535,7 +394,7 @@ return dlist_new;
 static gamgi_dlist *static_ok_y (gamgi_dlist *dlist_old,
 gamgi_bool action, gamgi_window *window)
 {
-gamgi_text *text;
+gamgi_orbital *orbital;
 gamgi_dlist *dlist, *dlist_new;
 gamgi_bool condition;
 double min, max;
@@ -554,13 +413,13 @@ DBL_MAX, &min, &max, window) == FALSE) return NULL;
 dlist_new = NULL;
 for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
   {
-  text = GAMGI_CAST_TEXT dlist->data;
-  condition = (text->origin[1] >= min && text->origin[1] <= max);
+  orbital = GAMGI_CAST_ORBITAL dlist->data;
+  condition = (orbital->origin[1] >= min && orbital->origin[1] <= max);
 
   if (condition != action)
     {
     dlist_new = gamgi_engine_dlist_add_start (dlist_new);
-    dlist_new->data = text;
+    dlist_new->data = orbital;
     }
   }
 
@@ -570,7 +429,7 @@ return dlist_new;
 static gamgi_dlist *static_ok_z (gamgi_dlist *dlist_old,
 gamgi_bool action, gamgi_window *window)
 {
-gamgi_text *text;
+gamgi_orbital *orbital;
 gamgi_dlist *dlist, *dlist_new;
 gamgi_bool condition;
 double min, max;
@@ -589,13 +448,13 @@ DBL_MAX, &min, &max, window) == FALSE) return NULL;
 dlist_new = NULL;
 for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
   {
-  text = GAMGI_CAST_TEXT dlist->data;
-  condition = (text->origin[2] >= min && text->origin[2] <= max);
+  orbital = GAMGI_CAST_ORBITAL dlist->data;
+  condition = (orbital->origin[2] >= min && orbital->origin[2] <= max);
 
   if (condition != action)
     {
     dlist_new = gamgi_engine_dlist_add_start (dlist_new);
-    dlist_new->data = text;
+    dlist_new->data = orbital;
     }
   }
 
@@ -605,7 +464,7 @@ return dlist_new;
 static gamgi_dlist *static_ok_e1 (gamgi_dlist *dlist_old,
 gamgi_bool action, gamgi_window *window)
 {
-gamgi_text *text;
+gamgi_orbital *orbital;
 gamgi_dlist *dlist, *dlist_new;
 gamgi_bool condition;
 double rotate[9], euler[3];
@@ -625,15 +484,15 @@ DBL_MAX, &min, &max, window) == FALSE) return NULL;
 dlist_new = NULL;
 for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
   {
-  text = GAMGI_CAST_TEXT dlist->data;
-  gamgi_math_quaternion_to_matrix (text->quaternion, rotate);
+  orbital = GAMGI_CAST_ORBITAL dlist->data;
+  gamgi_math_quaternion_to_matrix (orbital->quaternion, rotate);
   gamgi_math_euler_from_matrix (rotate, euler);
   condition = (euler[0] >= min && euler[0] <= max);
 
   if (condition != action)
     {
     dlist_new = gamgi_engine_dlist_add_start (dlist_new);
-    dlist_new->data = text;
+    dlist_new->data = orbital;
     }
   }
 
@@ -643,7 +502,7 @@ return dlist_new;
 static gamgi_dlist *static_ok_e2 (gamgi_dlist *dlist_old,
 gamgi_bool action, gamgi_window *window)
 {
-gamgi_text *text;
+gamgi_orbital *orbital;
 gamgi_dlist *dlist, *dlist_new;
 gamgi_bool condition;
 double rotate[9], euler[3];
@@ -663,15 +522,15 @@ DBL_MAX, &min, &max, window) == FALSE) return NULL;
 dlist_new = NULL;
 for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
   {
-  text = GAMGI_CAST_TEXT dlist->data;
-  gamgi_math_quaternion_to_matrix (text->quaternion, rotate);
+  orbital = GAMGI_CAST_ORBITAL dlist->data;
+  gamgi_math_quaternion_to_matrix (orbital->quaternion, rotate);
   gamgi_math_euler_from_matrix (rotate, euler);
   condition = (euler[1] >= min && euler[1] <= max);
 
   if (condition != action)
     {
     dlist_new = gamgi_engine_dlist_add_start (dlist_new);
-    dlist_new->data = text;
+    dlist_new->data = orbital;
     }
   }
 
@@ -681,7 +540,7 @@ return dlist_new;
 static gamgi_dlist *static_ok_e3 (gamgi_dlist *dlist_old,
 gamgi_bool action, gamgi_window *window)
 {
-gamgi_text *text;
+gamgi_orbital *orbital;
 gamgi_dlist *dlist, *dlist_new;
 gamgi_bool condition;
 double rotate[9], euler[3];
@@ -701,15 +560,15 @@ DBL_MAX, &min, &max, window) == FALSE) return NULL;
 dlist_new = NULL;
 for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
   {
-  text = GAMGI_CAST_TEXT dlist->data;
-  gamgi_math_quaternion_to_matrix (text->quaternion, rotate);
+  orbital = GAMGI_CAST_ORBITAL dlist->data;
+  gamgi_math_quaternion_to_matrix (orbital->quaternion, rotate);
   gamgi_math_euler_from_matrix (rotate, euler);
   condition = (euler[2] >= min && euler[2] <= max);
 
   if (condition != action)
     {
     dlist_new = gamgi_engine_dlist_add_start (dlist_new);
-    dlist_new->data = text;
+    dlist_new->data = orbital;
     }
   }
 
@@ -754,42 +613,6 @@ for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
 return dlist_new;
 }
 
-static gamgi_dlist *static_ok_font (gamgi_dlist *dlist_old,
-gamgi_bool action, gamgi_window *window)
-{
-gamgi_text *text;
-gamgi_dlist *dlist, *dlist_new;
-gamgi_bool condition;
-int min, max;
-int font;
-
-/********************
- * get range limits *
- ********************/
-
-gamgi_gtk_select_combo_int (&min, &max, window);
-
-/******************************
- * get list of selected texts *
- ******************************/
-
-dlist_new = NULL;
-for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
-  {
-  text = GAMGI_CAST_TEXT dlist->data;
-  font = static_font (text->font);
-  condition = (font >= min && font <= max);
-
-  if (condition != action)
-    {
-    dlist_new = gamgi_engine_dlist_add_start (dlist_new);
-    dlist_new->data = text;
-    }
-  }
-
-return dlist_new;
-}
-
 static gamgi_dlist *static_ok_red (gamgi_dlist *dlist_old,
 gamgi_bool action, gamgi_window *window)
 {
@@ -1014,9 +837,6 @@ else if (strcmp (name, "Text") == 0)
   dlist_new = static_ok_parent (dlist_old,
   action, GAMGI_ENGINE_TEXT, window);
 
-else if (strcmp (name, "Contents") == 0)
-  dlist_new = static_ok_contents (dlist_old, action, window);
-
 else if (strcmp (name, "X") == 0)
   dlist_new = static_ok_x (dlist_old, action, window);
 else if (strcmp (name, "Y") == 0)
@@ -1032,8 +852,6 @@ else if (strcmp (name, "E3") == 0)
 
 else if (strcmp (name, "Style") == 0)
   dlist_new = static_ok_style (dlist_old, action, window);
-else if (strcmp (name, "Font") == 0)
-  dlist_new = static_ok_font (dlist_old, action, window);
 else if (strcmp (name, "R") == 0)
   dlist_new = static_ok_red (dlist_old, action, window);
 else if (strcmp (name, "G") == 0)
@@ -1065,26 +883,26 @@ dlist_new = gamgi_engine_dlist_invert (dlist_new);
  * list Current when Scope is different     *
  ********************************************/
 
-if (dlist_old != static_before && dlist_old != gamgi->texts)
+if (dlist_old != static_before && dlist_old != gamgi->orbitals)
   gamgi_engine_dlist_remove_all (dlist_old);
 
 gamgi_engine_dlist_remove_all (static_before);
-static_before = gamgi->texts;
+static_before = gamgi->orbitals;
 
 if (scope == STATIC_CURRENT)
-  gamgi->texts = dlist_new;
+  gamgi->orbitals = dlist_new;
 else
-  gamgi_gtk_select_merge (&gamgi->texts, dlist_new);
+  gamgi_gtk_select_merge (&gamgi->orbitals, dlist_new);
 
-/*****************************************
- * Change color for Text label to signal *
- * that a list of selected texts exists  *
- *                                       *
- * reset dialog: the Scope list is set   *
- * to Current and the model is updated   *
- *****************************************/
+/*******************************************
+ * Change color for Text label to signal   *
+ * that a list of selected orbitals exists *
+ *                                         *
+ * reset dialog: the Scope list is set     *
+ * to Current and the model is updated     *
+ *******************************************/
 
-gamgi_global_selection_update_windows (&gamgi->texts, "button_text");
+gamgi_global_selection_update_windows (&gamgi->orbitals, "button_orbital");
 
 static_reset (window);
 }
@@ -1114,14 +932,14 @@ gtk_widget_set_size_request (vbox, size.width, size.height);
  **************************************************/
 
 static_before = NULL;
-gamgi_global_selection_unlink (gamgi->texts);
+gamgi_global_selection_unlink (gamgi->orbitals);
 
 /************************************
  * initialize Scope, Action, Method *
  ************************************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
-if (gamgi->texts == NULL)
+if (gamgi->orbitals == NULL)
   gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_LAYER);
 else
   gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_CURRENT);
@@ -1180,7 +998,7 @@ if ((event->state & GDK_CONTROL_MASK) == 0)
   {
   if (window_dialog == window_mouse)
     gamgi_mesa_select_object (window_mouse,
-    x, y, GAMGI_ENGINE_TEXT, FALSE, NULL);
+    x, y, GAMGI_ENGINE_ORBITAL, FALSE, NULL);
   }
 
 /*********************************************************
@@ -1191,7 +1009,7 @@ if ((event->state & GDK_CONTROL_MASK) == 0)
 
 else
   gamgi_mesa_select_object (window_mouse,
-  x, y, GAMGI_ENGINE_TEXT, TRUE, static_press);
+  x, y, GAMGI_ENGINE_ORBITAL, TRUE, static_press);
 }
 
 void gamgi_gtk_orbital_select (GtkWidget *widget, void *data)
@@ -1218,8 +1036,8 @@ GtkTreeIter iter, child;
  * dialog level 0 *
  ******************/
 
-dialog = gamgi_gtk_dialog_task0_create ("Text Select", window);
-window->action = GAMGI_GTK_TEXT_SELECT;
+dialog = gamgi_gtk_dialog_task0_create ("Orbital Select", window);
+window->action = GAMGI_GTK_ORBITAL_SELECT;
 gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 g_signal_connect (dialog, "destroy", G_CALLBACK (static_destroy), window);
 
@@ -1436,13 +1254,39 @@ gtk_tree_store_append (tree_store, &child, &iter);
 gtk_tree_store_set (tree_store, &child, 0, "Atom", -1);
 gtk_tree_store_append (tree_store, &child, &iter);
 gtk_tree_store_set (tree_store, &child, 0, "Bond", -1);
-gtk_tree_store_append (tree_store, &child, &iter);
-gtk_tree_store_set (tree_store, &child, 0, "Orbital", -1);
-gtk_tree_store_append (tree_store, &child, &iter);
-gtk_tree_store_set (tree_store, &child, 0, "Text", -1);
 
 gtk_tree_store_append (tree_store, &iter, NULL);
-gtk_tree_store_set (tree_store, &iter, 0, "Contents", -1);
+gtk_tree_store_set (tree_store, &iter, 0, "Type", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "N", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "L", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "M", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Charge", -1);
+
+gtk_tree_store_append (tree_store, &iter, NULL);
+gtk_tree_store_set (tree_store, &iter, 0, "Model", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Style", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Density", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Sampling", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Radius", -1);
+
+gtk_tree_store_append (tree_store, &iter, NULL);
+gtk_tree_store_set (tree_store, &iter, 0, "Volume", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Phase", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Frame", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Octants", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Axes", -1);
 
 gtk_tree_store_append (tree_store, &iter, NULL);
 gtk_tree_store_set (tree_store, &iter, 0, "Position", -1);
@@ -1462,15 +1306,26 @@ gtk_tree_store_set (tree_store, &child, 0, "E3", -1);
 gtk_tree_store_append (tree_store, &iter, NULL);
 gtk_tree_store_set (tree_store, &iter, 0, "View", -1);
 gtk_tree_store_append (tree_store, &child, &iter);
-gtk_tree_store_set (tree_store, &child, 0, "Style", -1);
+gtk_tree_store_set (tree_store, &child, 0, "Color_R", -1);
 gtk_tree_store_append (tree_store, &child, &iter);
-gtk_tree_store_set (tree_store, &child, 0, "Font", -1);
+gtk_tree_store_set (tree_store, &child, 0, "Color_G", -1);
 gtk_tree_store_append (tree_store, &child, &iter);
-gtk_tree_store_set (tree_store, &child, 0, "R", -1);
+gtk_tree_store_set (tree_store, &child, 0, "Color_B", -1);
+
 gtk_tree_store_append (tree_store, &child, &iter);
-gtk_tree_store_set (tree_store, &child, 0, "G", -1);
+gtk_tree_store_set (tree_store, &child, 0, "Phase_R", -1);
 gtk_tree_store_append (tree_store, &child, &iter);
-gtk_tree_store_set (tree_store, &child, 0, "B", -1);
+gtk_tree_store_set (tree_store, &child, 0, "Phase_G", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Phase_B", -1);
+
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Frame_R", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Frame_G", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Frame_B", -1);
+
 gtk_tree_store_append (tree_store, &child, &iter);
 gtk_tree_store_set (tree_store, &child, 0, "Scale", -1);
 
@@ -1514,8 +1369,6 @@ gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
 g_object_set_data (G_OBJECT (dialog), "widget_min", combo);
 gtk_widget_show (combo);
 
-gamgi_gtk_text_config_all (combo);
-
 renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
@@ -1541,8 +1394,6 @@ gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
 g_object_set_data (G_OBJECT (dialog), "widget_max", combo);
 gtk_widget_show (combo);
 
-gamgi_gtk_text_config_all (combo);
-
 renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
