@@ -460,18 +460,6 @@ GtkWidget *dialog = window->dialog0;
 
 plane->reference = GAMGI_ENGINE_ATOM;
 
-/******************
- * get plane name *
- ******************/
-
-if (gamgi_gtk_object_name (dialog, "entry_plane",
-"Plane", plane->object.name) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid plane name", window);
-  gamgi_engine_remove_plane (plane);
-  return FALSE;
-  }
-
 /***********************
  * get reference atoms *
  ***********************/
@@ -729,6 +717,19 @@ gamgi_enum structure, filter;
 plane = gamgi_engine_create_plane ();
 gamgi_engine_start_plane (plane);
 
+/******************************************
+ * get name (set empty default, to handle *
+ * it later, when h,k,l indices are known *
+ ******************************************/
+
+if (gamgi_gtk_object_name (dialog, "entry_plane",
+"", plane->object.name) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid Plane name", window);
+  gamgi_engine_remove_plane (plane);
+  return;
+  }
+
 /***********************************
  * this unneeded initialization    *
  * avoids a O3 compilation warning *
@@ -800,6 +801,7 @@ if (plane->reference == GAMGI_ENGINE_CELL)
   gamgi_gtk_plane_list_create (plane, cell, structure,
   filter, thickness, dlist, start, end, pole, trace);
 
+  gamgi_gtk_plane_list_cancel (NULL, window);
   while (dlist != NULL)
     dlist = gamgi_engine_dlist_remove_start (dlist);
   gamgi_engine_remove_plane (plane);
@@ -814,6 +816,8 @@ if (plane->reference == GAMGI_ENGINE_ATOM)
    * the plane type is needed because of the rotation next  *
    **********************************************************/
 
+  if (strcmp (plane->object.name, "") == 0)
+    strcpy (plane->object.name, "Plane");
   plane->type = GAMGI_PHYS_POLYGON;
   plane->vectors = GAMGI_PHYS_PLANE_VECTORS;
 
