@@ -83,6 +83,77 @@ double translation[3], rotation[3];
 float red, green, blue;
 double scale; } cache;
 
+static void static_name (gamgi_window *window, char *name)
+{
+gamgi_plane *plane;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+GtkWidget *button;
+char string[GAMGI_ENGINE_STRING];
+int active;
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_plane");
+
+plane = GAMGI_CAST_PLANE gamgi_gtk_object_number (dialog,
+"entry_plane", GAMGI_ENGINE_PLANE, window, string);
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
+
+if (active == TRUE || plane == NULL)
+  {
+  sprintf (string, "%s", name);
+  }
+else
+  {
+  if (strcmp (name, "") == 0)
+    sprintf (string, "%s %d", plane->object.name, plane->object.number);
+  else
+    sprintf (string, "%s %d", name, plane->object.number);
+  }
+
+gtk_entry_set_text (GTK_ENTRY (entry), string);
+}
+
+static void static_indices (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+char token[GAMGI_ENGINE_TOKEN] = "";
+const char *name;
+gamgi_bool out;
+int h, k, l;
+
+/*********************
+ * Get plane indices *
+ *********************/
+
+out = TRUE;
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_h");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+out = out && gamgi_io_token_int_scan (name, &h, -INT_MAX, INT_MAX);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_k");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+out = out && gamgi_io_token_int_scan (name, &k, -INT_MAX, INT_MAX);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_l");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+out = out && gamgi_io_token_int_scan (name, &l, -INT_MAX, INT_MAX);
+
+out = out && (h != 0 || k != 0 || l != 0);
+
+/*********************
+ * update plane name *
+ *********************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_plane");
+if (out == TRUE) gamgi_phys_plane_name (h, k, l, token);
+static_name (window, token);
+}
+
 static void static_atom_remove (gamgi_plane *plane, gamgi_bool *link)
 {
 if (cache.structure != GAMGI_CHEM_STRUCTURE_LINK)
@@ -1763,14 +1834,6 @@ if (class == GAMGI_ENGINE_PLANE)
   {
   plane = GAMGI_CAST_PLANE object;
 
-  /****************************
-   * set plane identification *
-   ****************************/
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_plane");
-  sprintf (string, "%s %d", object->name, object->number);
-  gtk_entry_set_text (GTK_ENTRY (entry), string);
-
   combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
   if (plane->reference == GAMGI_ENGINE_CELL)
     {
@@ -1917,6 +1980,14 @@ if (class == GAMGI_ENGINE_PLANE)
   entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
   sprintf (string, "%.*f", GAMGI_MATH_DECIMAL_SCALE, plane->object.scale);
   gtk_entry_set_text (GTK_ENTRY (entry), string);
+
+  /**********************************************************************
+   * set plane identification at the end, after automatic name setting! *
+   **********************************************************************/
+
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_plane");
+  sprintf (string, "%s %d", object->name, object->number);
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
   }
 
 else if (class == GAMGI_ENGINE_CELL)
@@ -2186,6 +2257,8 @@ entry = gtk_entry_new ();
 gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 0, 1, GTK_EXPAND, GTK_FILL, 0, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+g_signal_connect (entry, "changed",
+G_CALLBACK (static_indices), window);
 g_object_set_data (G_OBJECT (dialog), "entry_h", entry);
 gtk_widget_show (entry);
 
@@ -2193,6 +2266,8 @@ entry = gtk_entry_new ();
 gtk_table_attach (GTK_TABLE (table), entry, 3, 4, 0, 1, GTK_EXPAND, GTK_FILL, 0, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+g_signal_connect (entry, "changed",
+G_CALLBACK (static_indices), window);
 g_object_set_data (G_OBJECT (dialog), "entry_k", entry);
 gtk_widget_show (entry);
 
@@ -2200,6 +2275,8 @@ entry = gtk_entry_new ();
 gtk_table_attach (GTK_TABLE (table), entry, 5, 6, 0, 1, GTK_EXPAND, GTK_FILL, 0, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+g_signal_connect (entry, "changed",
+G_CALLBACK (static_indices), window);
 g_object_set_data (G_OBJECT (dialog), "entry_l", entry);
 gtk_widget_show (entry);
 
