@@ -167,16 +167,33 @@ if (class >= GAMGI_ENGINE_ORBITAL)
 
   dots = orbital->dots;
 
-  glLineWidth (4.0);
-  if (dots[1] > 0)
-    gamgi_mesa_render_points (dots[1], orbital->points + 3 * dots[0]);
-  if (dots[2] > 0)
-    gamgi_mesa_render_points (dots[2], orbital->points + 3 * dots[0] + 3 * dots[1]);
-  glLineWidth (1.0);
+  if (orbital->style == GAMGI_MESA_WIRED)
+    {
+    glLineWidth (4.0);
+    if (dots[1] > 0)
+      gamgi_mesa_render_points (dots[1],
+      orbital->points + 3 * dots[0]);
+    if (dots[2] > 0)
+      gamgi_mesa_render_points (dots[2],
+      orbital->points + 3 * dots[0] + 3 * dots[1]);
+    glLineWidth (1.0);
+    }
 
-  if (dots[0] > 0)
+  if (orbital->style == GAMGI_MESA_SOLID)
+    {
+    glDisable (GL_CULL_FACE);
+    if (dots[1] > 0)
+      gamgi_mesa_render_triangles (dots[1] / 3,
+      orbital->points + 3 * dots[0]);
+    if (dots[2] > 0)
+      gamgi_mesa_render_triangles (dots[2] / 3,
+      orbital->points + 3 * dots[0] + 3 * dots[1]);
+    glEnable (GL_CULL_FACE);
+    }
+
+  if (orbital->frame == TRUE)
     gamgi_mesa_render_lines (orbital->lines, orbital->points);
-  if (orbital->axes == TRUE)
+  if (orbital->axes > 0.0)
     gamgi_mesa_axes_orbital (orbital, FALSE);
 
   glPopMatrix ();
