@@ -389,7 +389,6 @@ double *normal, gamgi_bool link)
 gamgi_direction *direction_new;
 int node_p[3];
 gamgi_bool inside;
-
 int uvw[3];
 
 /************************
@@ -398,6 +397,10 @@ int uvw[3];
 
 direction_new = gamgi_engine_copy_direction (direction);
 
+if (strcmp (direction->object.name, "") == 0)
+  gamgi_phys_direction_name (direction->uvw[0], direction->uvw[1],
+  direction->uvw[2], direction_new->object.name);
+
 node_p[swap[0]] = node[0];
 node_p[swap[1]] = node[1];
 node_p[swap[2]] = node[2];
@@ -451,6 +454,39 @@ else gamgi_engine_remove_direction (direction_new);
 return inside;
 }
 
+static void static_projection (gamgi_direction *direction,
+gamgi_cell *cell, gamgi_enum type)
+{
+gamgi_direction *direction_new;
+
+/******************************************************************
+ * Direction Create: direction is just a template, removed in the *
+ * end, used to copy data to direction_new, the real direction    *
+ *                                                                *
+ * Direction Modify: direction is the real direction to modify    *
+ *                                                                *
+ * direction->object.object is used here as a flag to distinguish *
+ * between the two cases. direction->object.object can be used    *
+ * because direction is always unlinked at this stage             *
+ ******************************************************************/
+
+if (direction->object.object == NULL)
+  direction_new = gamgi_engine_copy_direction (direction);
+else
+  { direction_new = direction; direction->object.object = NULL; }
+
+if (strcmp (direction->object.name, "") == 0)
+  gamgi_phys_direction_name (direction->uvw[0], direction->uvw[1],
+  direction->uvw[2], direction_new->object.name);
+direction_new->type = type;
+
+gamgi_phys_projection_create (direction_new->type, &direction_new->points,
+&direction_new->n_points, &direction_new->loops, &direction_new->n_loops);
+
+gamgi_engine_link_direction_cell (direction_new, cell);
+gamgi_mesa_rotate_out_direction (direction_new, NULL, NULL, NULL);
+}
+
 gamgi_bool gamgi_phys_direction_zero (int *a)
 {
 /****************************************
@@ -879,6 +915,30 @@ GAMGI_CAST_OBJECT atom2, GAMGI_CAST_OBJECT window->layer);
 return parent;
 }
 
+void gamgi_phys_direction_line (gamgi_direction *direction, double *points)
+{
+int i;
+
+/********************************
+ * build points array: 2 points *
+ ********************************/
+
+direction->points = (double *) malloc (sizeof (double) * 6);
+for (i = 0; i < 6; i++) direction->points[i] = points[i];
+direction->n_points = 2;
+
+/*****************************
+ * build loops array: 1 line *
+ *****************************/
+
+direction->loops = (int *) malloc (sizeof (int) * 3);
+direction->loops[0] = 1;
+direction->loops[1] = 0;
+direction->loops[2] = 1;
+
+direction->n_loops = 3;
+}
+
 gamgi_bool gamgi_phys_direction_reference (gamgi_direction *direction,
 gamgi_atom **atom1, gamgi_atom **atom2)
 {
@@ -1279,6 +1339,10 @@ if (direction->object.object == NULL)
 else
   { direction_new = direction; direction->object.object = NULL; }
 
+if (strcmp (direction->object.name, "") == 0)
+  gamgi_phys_direction_name (direction->uvw[0], direction->uvw[1],
+  direction->uvw[2], direction_new->object.name);
+
 /*********************************************
  * 1) build new direction and link to cell   *
  * 2) get normalized direction vector,       *
@@ -1307,54 +1371,11 @@ if (structure == GAMGI_CHEM_STRUCTURE_LINK)
 void gamgi_phys_direction_projection (gamgi_direction *direction,
 gamgi_cell *cell, gamgi_enum pole, gamgi_enum trace)
 {
-gamgi_direction *direction_new;
-
-/******************************************************************
- * Direction Create: direction is just a template, removed in the *
- * end, used to copy data to direction_new, the real direction    *
- *                                                                *
- * Direction Modify: direction is the real direction to modify    *
- *                                                                *
- * direction->object.object is used here as a flag to distinguish *
- * between the two cases. direction->object.object can be used    *
- * because direction is always unlinked at this stage             *
- ******************************************************************/
-
-if (direction->object.object == NULL)
-  direction_new = gamgi_engine_copy_direction (direction);
-else
-  { direction_new = direction; direction->object.object = NULL; }
-
-if (pole == TRUE) direction_new->type = GAMGI_PHYS_POLE;
-if (trace == TRUE) direction_new->type = GAMGI_PHYS_TRACE;
-
-gamgi_phys_projection_create (direction_new->type, &direction_new->points,
-&direction_new->n_points, &direction_new->loops, &direction_new->n_loops);
-
-gamgi_engine_link_direction_cell (direction_new, cell);
-gamgi_mesa_rotate_out_direction (direction_new, NULL, NULL, NULL);
+if (pole == TRUE) static_projection (direction, cell, GAMGI_PHYS_POLE);
+if (trace == TRUE) static_projection (direction, cell, GAMGI_PHYS_TRACE);
 }
 
-void gamgi_phys_direction_line (gamgi_direction *direction, double *points)
+void gamgi_phys_direction_name (int u, int v, int w, char *token)
 {
-int i;
-
-/********************************
- * build points array: 2 points *
- ********************************/
-
-direction->points = (double *) malloc (sizeof (double) * 6);
-for (i = 0; i < 6; i++) direction->points[i] = points[i];
-direction->n_points = 2;
-
-/*****************************
- * build loops array: 1 line *
- *****************************/
-
-direction->loops = (int *) malloc (sizeof (int) * 3);
-direction->loops[0] = 1;
-direction->loops[1] = 0;
-direction->loops[2] = 1;
-
-direction->n_loops = 3;
+sprintf (token, "[%d.%d.%d]", u, v, w);
 }
