@@ -41,6 +41,9 @@ static gamgi_bool static_range (gamgi_direction *direction, gamgi_cell *cell,
 gamgi_enum structure, double thickness, gamgi_dlist *dlist, int *node, int *swap,
 double *normal, gamgi_bool link);
 
+static void static_projection (gamgi_direction *direction,
+gamgi_cell *cell, gamgi_enum type);
+
  **********************
  * external functions *
  **********************/
@@ -77,6 +80,8 @@ gamgi_cell *cell);
 gamgi_object *gamgi_phys_direction_parent (gamgi_atom *atom1,
 gamgi_atom *atom2, gamgi_window *window);
 
+void gamgi_phys_direction_line (gamgi_direction *direction, double *points);
+
 gamgi_bool gamgi_phys_direction_reference (gamgi_direction *direction,
 gamgi_atom **atom1, gamgi_atom **atom2);
 
@@ -103,14 +108,14 @@ gamgi_enum structure, gamgi_enum filter, double thickness, gamgi_dlist *dlist);
 void gamgi_phys_direction_projection (gamgi_direction *direction,
 gamgi_cell *cell, gamgi_enum pole, gamgi_enum trace);
 
-void gamgi_phys_direction_line (gamgi_direction *direction, double *points);
+void gamgi_phys_direction_name (int u, int v, int w, char *token);
 
 /*************
  * Rationale *
  *************
 
-Needs cleaning.
-- 09 Aug 05 -
+Last update:
+- 26 Oct 13 -
 
  *************
  * Rationale *
