@@ -1012,6 +1012,8 @@ if (plane->object.object == NULL)
 else
   { plane_new = plane; plane->object.object = NULL; }
 
+if (strcmp (plane->object.name, "") == 0) gamgi_phys_plane_name
+(plane->hkl[0], plane->hkl[1], plane->hkl[2], plane_new->object.name);
 plane_new->order = order;
 
 /*******************
@@ -1042,6 +1044,39 @@ else gamgi_engine_remove_plane (plane_new);
 return inside;
 }
 
+static void static_projection (gamgi_plane *plane,
+gamgi_cell *cell, gamgi_enum type)
+{
+gamgi_plane *plane_new;
+
+/**************************************************************
+ * Plane Create: plane is just a template, removed in the     *
+ * end, used to copy data to plane_new, the real plane        *
+ *                                                            *
+ * Plane Modify: plane is the real plane to modify            *
+ *                                                            *
+ * plane->object.object is used here as a flag to distinguish *
+ * between the two cases. plane->object.object can be used    *
+ * because plane is always unlinked at this stage             *
+ **************************************************************/
+
+if (plane->object.object == NULL)
+  plane_new = gamgi_engine_copy_plane (plane);
+else
+  { plane_new = plane; plane->object.object = NULL; }
+
+if (strcmp (plane->object.name, "") == 0)
+  gamgi_phys_plane_name (plane->hkl[0], plane->hkl[1],
+  plane->hkl[2], plane_new->object.name);
+plane_new->type = type;
+
+gamgi_phys_projection_create (plane_new->type, &plane_new->points,
+&plane_new->n_points, &plane_new->loops, &plane_new->n_loops);
+
+gamgi_engine_link_plane_cell (plane_new, cell);
+gamgi_mesa_rotate_out_plane (plane_new, NULL, NULL, NULL);
+}
+
 int gamgi_phys_plane_order (gamgi_cell *cell, 
 int *hkl, gamgi_enum vectors, int o1, int o2, int o3)
 {
@@ -1866,30 +1901,11 @@ else
 void gamgi_phys_plane_projection (gamgi_plane *plane,
 gamgi_cell *cell, gamgi_enum pole, gamgi_enum trace)
 {
-gamgi_plane *plane_new;
+if (pole == TRUE) static_projection (plane, cell, GAMGI_PHYS_POLE);
+if (trace == TRUE) static_projection (plane, cell, GAMGI_PHYS_TRACE);
+}
 
-/**************************************************************
- * Plane Create: plane is just a template, removed in the     *
- * end, used to copy data to plane_new, the real plane        *
- *                                                            *
- * Plane Modify: plane is the real plane to modify            *
- *                                                            *
- * plane->object.object is used here as a flag to distinguish *
- * between the two cases. plane->object.object can be used    *
- * because plane is always unlinked at this stage             *
- **************************************************************/
-
-if (plane->object.object == NULL)
-  plane_new = gamgi_engine_copy_plane (plane);
-else
-  { plane_new = plane; plane->object.object = NULL; }
-
-if (pole == TRUE) plane_new->type = GAMGI_PHYS_POLE;
-if (trace == TRUE) plane_new->type = GAMGI_PHYS_TRACE;
-
-gamgi_phys_projection_create (plane_new->type, &plane_new->points,
-&plane_new->n_points, &plane_new->loops, &plane_new->n_loops);
-
-gamgi_engine_link_plane_cell (plane_new, cell);
-gamgi_mesa_rotate_out_plane (plane_new, NULL, NULL, NULL);
+void gamgi_phys_plane_name (int h, int k, int l, char *token)
+{
+sprintf (token, "(%d.%d.%d)", h, k, l);
 }
